@@ -20,20 +20,20 @@ class ats_system(object):
         config = ''
         for line in self._d.cmd('show running-config').replace('\r','').split('\n'):
             config += line+'\n'
-            if line.startswith("end"):
-               break
         self._d.log_debug('got device configuration \n{0}'.format(config))
         return config
 
     def shell_init(self):
         self._d.log_info('shell_init')
-        return [{'cmd': 'terminal datadump', 'prompt':r'[\n\r]+[\w\_]+\#'},]
+        return [{'cmd': 'terminal datadump', 'prompt':'\#'},]
 
     def shell_prompt(self):
         self._d.log_info('shell_prompt')
-        return r'[\n\r]{1}[\w\_]*[\>\#]{1}'
+        return r'[\>\#]'
 
     def ping(self):
         self._d.log_info('ping')
-        self._d.cmd('show version')
+        self._d.cmd('show version', use_cache=False)
+
+
         
